<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller\CrudWithParameterBag;

class ModeloImpressora extends CrudWithParameterBag {
    protected $parameterBag;
    
    public function __construct (Services\ModeloImpressoraService $ModeloImpressoraService, ParameterBag $parameterBag, Manager $dataSourceManager, $crudService){
        $this->modeloImpressoraService = $ModeloImpressoraService;
        $this->crudService = $crudService;
        parent::__construct($dataSourceManager, $parameterBag);
    }
    
    protected $dataSourceNameArray = array (
        'modelo_impressora' => 'vnd90100_modeloImpressora'
    );
    protected $parameterBagColumnsArray = array (
        'modelo_impressora' => array('NRORG')
    );
    
    private function adqNovoCodigo($NRORG) {
        $params = array(
           ':NRORG' => $NRORG
        );
        
        $resultadoService = $this->modeloImpressoraService->getNovoCodigo($params);
        return $resultadoService;
    }
    
    private function deleteCrud(DTO\Request $request, DTO\Response $response) {
        try {
            $request = $this->crudService->buildDataSetIfRow($request, $this->dataSourceName);
            $dataSet = $request->getDataSet();
            $dataSet->setDataSourceName($this->dataSourceName);
            $this->crudService->delete($response, $dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function getNovoCodigo(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $cdsNovoCodigo = $this->adqNovoCodigo($row['NRORG']);
        print str_pad($cdsNovoCodigo[0]['NOVOCODIGO'], 3, "0", STR_PAD_LEFT);
    }
    
    public function findImpressoras (DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['modelo_impressora'];
        $this->parameterBagColumns = $this->parameterBagColumnsArray['modelo_impressora'];
        parent::find($request, $response);
    }
    
    public function saveImpressoras(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['modelo_impressora'];
        $this->parameterBagColumns = $this->parameterBagColumnsArray['modelo_impressora'];
        parent::save($request, $response);
    }
    
    public function deleteImpressoras(DTO\Request\Row $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['modelo_impressora'];
        $this->deleteCrud($request, $response);
    }
}